<?php

class ZServer_Cli_Tool_Command_Manage_ClusterRemoveServer extends ZServer_Cli_Tool_Command_Manage_Abstract
{
    protected $_description = 'remove a server from Zend Server Cluster Manager';
    
    protected $_usageMessage = '<server ID> [options]';
    
    protected $_args = array(
        'r|retry=i' => 'retry action <value> times if server is locked; default is 3',
        'w|wait=i'  => 'wait <value> seconds between retires; default is 5',
        's|sync'    => 'run synchronously; wait for Graceful Shutdown to complete',
        'f|force'   => 'force remove the server; ' 
    );
    
    protected function _run()
    {
        $force = $this->_tool->getArguments()->f;
        $retry = $this->_tool->getArguments()->r;
        $wait  = $this->_tool->getArguments()->w;
        $sync  = $this->_tool->getArguments()->s;
        
        $args = $this->_tool->getArguments()->getRemainingArgs();
        $serverId = (int) array_shift($args);
        
        if (! $serverId) { 
            // Error: missing server ID
            throw new ZServer_Cli_Tool_Command_Exception("missing or invalid server ID", ZServer_Cli_Tool::EXIT_INVALID_ARG);
        }
        
        if (! empty($args)) {
            // Error: too many arguments
            throw new ZServer_Cli_Tool_Command_Exception("unexpected number of arguments, expecting exactly one argument", ZServer_Cli_Tool::EXIT_INVALID_ARG);
        }
        
	   	if ($retry < 1) $retry = 3;  
		if ($wait < 1) $wait = 5;        
        $this->_getZsApiClient()->setRetryIfLocked($retry, $wait);
        if ($force) {
        	$serverInfo = $this->_getZsApiClient()->clusterForceRemoveServer($serverId);
        } else {
        	$serverInfo = $this->_getZsApiClient()->clusterRemoveServer($serverId);
        }
        if ($sync) {
        		for($i = 0; $i < 300; $i ++) {
        			try {
	        			$count=$this->_getZsApiClient()->clusterGetServersCount();
	        		
		        		if ((string)(int)$count != $count || $count!=0){ 
		        		}else {
		        			break;
		        		}
	        		}catch (ZendX_Service_ZendServer_Exception $ex) {
	        		}
	        		sleep (2);
	        	}
        	
        }
        
        $this->_printServerInfo($serverInfo);
    }
}